@@ -103,14 +103,14 @@ add_cbc_solver <- function(x,
                            start_solution = NULL,
                            verbose = TRUE) {
   # assert that arguments are valid (except start_solution)
-  rlang::check_required(x)
-  rlang::check_required(gap)
-  rlang::check_required(time_limit)
-  rlang::check_required(presolve)
-  rlang::check_required(threads)
-  rlang::check_required(first_feasible)
-  rlang::check_required(start_solution)
-  rlang::check_required(verbose)
+  assert_required(x)
+  assert_required(gap)
+  assert_required(time_limit)
+  assert_required(presolve)
+  assert_required(threads)
+  assert_required(first_feasible)
+  assert_required(start_solution)
+  assert_required(verbose)
   assert(
     is_conservation_problem(x),
     assertthat::is.number(gap),
