@@ -243,14 +243,6 @@ NULL
 #'   p1 %>% add_connectivity_penalties(penalties[2], data = c_matrix)
 #' )
 #'
-#' # assign names to the problems
-#' names(p2) <- c(
-#'   "basic problem",
-#'   paste0("b_matrix (", penalties,")"),
-#'   paste0("d_matrix (", penalties,")"),
-#'   paste0("c_matrix (", penalties,")")
-#' )
-#'
 #' # solve problems
 #' s2 <- lapply(p2, solve)
 #'
@@ -268,8 +260,15 @@ NULL
 #'   geometry = sf::st_geometry(s2[[1]])
 #' )
 #'
+#' names(s2)[1:7] <- c(
+#'   "basic problem",
+#'   paste0("b_matrix (", penalties,")"),
+#'   paste0("d_matrix (", penalties,")"),
+#'   paste0("c_matrix (", penalties,")")
+#' )
+#'
 #' # plot solutions
-#' plot(s2, main = names(p2))
+#' plot(s2)
 #'
 #' # create minimal multi-zone problem and limit solver to one minute
 #' # to obtain solutions in a short period of time
@@ -409,10 +408,10 @@ NULL
 methods::setGeneric("add_connectivity_penalties",
   signature = methods::signature("x", "penalty", "zones", "data"),
   function(x, penalty, zones = diag(number_of_zones(x)), data) {
-    rlang::check_required(x)
-    rlang::check_required(penalty)
-    rlang::check_required(zones)
-    rlang::check_required(data)
+    assert_required(x)
+    assert_required(penalty)
+    assert_required(zones)
+    assert_required(data)
     assert(
       is_conservation_problem(x),
       is_inherits(
