@@ -17,7 +17,7 @@ NULL
 #' @param x [problem()] object.
 #'
 #' @param targets `data.frame` or [tibble::tibble()] object.
-#'   See the Target data format section for more information.
+#'   See the Targets format section for more information.
 #'
 #' @inherit add_absolute_targets details
 #'
@@ -31,8 +31,10 @@ NULL
 #' \item{feature}{`character` name of features in argument
 #'   to `x`.}
 #'
-#' \item{zone}{`character` name of zones in argument to
-#'   `x`. This column is optional for arguments to `x`
+#' \item{zone}{`character` name of zones in the argument
+#'   `x`. It can also be a `list` of `character` vectors if
+#'   targets should correspond to multiple zones (see Examples section below).
+#'   This column is optional for arguments to `x`
 #'   that do not contain multiple zones.}
 #'
 #' \item{type}{`character` describing the type of target.
@@ -242,8 +244,8 @@ methods::setGeneric(
   "add_manual_targets",
   signature = methods::signature("x", "targets"),
   function(x, targets) {
-    rlang::check_required(x)
-    rlang::check_required(targets)
+    assert_required(x)
+    assert_required(targets)
     assert(
       is_conservation_problem(x),
       is.data.frame(targets)
