@@ -22,8 +22,8 @@ methods::setGeneric(
   "planning_unit_solution_status",
   signature = methods::signature("x", "solution"),
   function(x, solution, ...) {
-    rlang::check_required(x)
-    rlang::check_required(solution)
+    assert_required(x)
+    assert_required(solution)
     assert(
       is_conservation_problem(x),
       is_inherits(
