@@ -38,9 +38,10 @@ NULL
 #'
 #'   \item{**`x` has [sf::st_sf()] or `data.frame` planning units**}{
 #'     The argument to `features` can be a `character` vector
-#'     with column names that correspond to the abundance or occurrence of
-#'     different features in each planning unit. Note that this argument
-#'     type can only be used to create problems involving a single zone.}
+#'     with column names (from `x`) that correspond to the abundance or
+#'     occurrence of different features in each planning unit. Note that
+#'     this argument type can only be used to create problems involving a
+#'     single zone.}
 #'
 #'   \item{**`x` has `data.frame`, `matrix`, or `numeric` vector planning
 #'      units**}{
@@ -78,7 +79,7 @@ NULL
 #'
 #'   \item{**`x` has [sf::st_sf()] or `data.frame` planning units**}{
 #'    The argument to `features` can be a [`ZonesCharacter`][zones()]
-#'    object with column names that correspond to the abundance or
+#'    object with column names (from `x`) that correspond to the abundance or
 #'    occurrence of different features in each planning unit in different
 #'    zones.}
 #'
@@ -119,7 +120,7 @@ NULL
 #'    to `x` is a `numeric` or `matrix` object.
 #'
 #' @param zones `data.frame` containing information on the zones. This
-#'   argument is only used when argument to `x` and `y` are
+#'   argument is only used when argument to `x` and `features` are
 #'   both `data.frame` objects and the problem being built contains
 #'   multiple zones. Following conventions used in `MarZone`, this
 #'   argument should contain the following columns:
@@ -155,7 +156,7 @@ NULL
 #' First, you will need to create a set of planning units
 #' (i.e., discrete spatial areas) to inform decision making.
 #' Planning units are often created by subdividing a study region
-#' into a set square or hexagonal cells. They can also be created using
+#' into a set of square or hexagonal cells. They can also be created using
 #' administrative boundaries (e.g., provinces), land management boundaries
 #' (e.g., property boundaries derived from cadastral data), or
 #' ecological boundaries (e.g., based on ecosystem classification data).
@@ -166,7 +167,7 @@ NULL
 #' (e.g., RAM and number of CPU cores on your computer).
 #'
 #' Second, you will need data to quantify the cost of implementing
-#' implementing each management action within each planning unit.
+#' each management action within each planning unit.
 #' Critically, the cost data should reflect the management action(s)
 #' considered in the exercise.
 #' For example, costs are often specified using data that reflect economic
@@ -175,14 +176,14 @@ NULL
 #' opportunity costs of foregone commercial activities
 #' (e.g., logging or agriculture), or
 #' opportunity costs of foregone recreational activities
-#' (e.g., recreational fishing) activities,
+#' (e.g., recreational fishing).
 #' In some cases -- depending on the management action(s) considered --
 #' it can make sense to use a constant cost value
 #' (e.g., all planning units are assigned a cost value equal to one)
 #' or use a cost value based on spatial extent
 #' (e.g., each planning unit is assigned a cost value based on its total area).
 #' Also, in most cases, you want to avoid negative cost values.
-#' This because a negative value means that a place is *desirable*
+#' This is because a negative value means that a place is *desirable*
 #' for implementing a management action, and such places will almost
 #' always be selected for prioritization even if they provide no benefit.
 #'
@@ -198,7 +199,7 @@ NULL
 #' presence or absence), area of occurrence within each planning unit
 #' (e.g., based on species' geographic range data), or
 #' a measure of habitat suitability (e.g., estimated using a statistical model).
-#' After compiling these data, you have the minimal data need to generate
+#' After compiling these data, you have the minimal data needed to generate
 #' a prioritization.
 #'
 #' A systematic conservation planning exercise involves prioritizing a set of
@@ -486,8 +487,8 @@ methods::setGeneric(
   "problem",
   signature = methods::signature("x", "features"),
   function(x, features, ...) {
-    rlang::check_required(x)
-    rlang::check_required(features)
+    assert_required(x)
+    assert_required(features)
     assert(
       is_inherits(
         x,
@@ -640,6 +641,14 @@ methods::setMethod(
         )
       )
     )
+    assert(
+      all_columns_inherit(
+        x[, unlist(as.list(features)), drop = FALSE], c("integer", "numeric")
+      ),
+      msg = c(
+        "{.arg features} must refer to {.cls numeric} columns of {.arg x}."
+      )
+    )
     verify(
       all_positive(x[, cost_column, drop = FALSE]),
       any_nonzero(x[, cost_column, drop = FALSE]),
@@ -652,6 +661,7 @@ methods::setMethod(
       r <- t(as.matrix(x[pos, z, drop = FALSE]))
       r[is.na(r)] <- 0
       rownames(r) <- feature_names(features)
+      colnames(r) <- NULL
       methods::as(r, "sparseMatrix")
     })
     names(rij) <- zone_names(features)
@@ -1107,6 +1117,14 @@ methods::setMethod(
         )
       )
     )
+    assert(
+      all_columns_inherit(
+        x[, unlist(as.list(features)), drop = FALSE], c("integer", "numeric")
+      ),
+      msg = c(
+        "{.arg features} must refer to {.cls numeric} columns of {.arg x}."
+      )
+    )
     verify(
       all_positive(x[, cost_column]),
       any_nonzero(x[, cost_column]),
