@@ -1,5 +1,3 @@
-context("add_gurobi_solver")
-
 test_that("binary decisions", {
   skip_on_cran()
   skip_if_not_installed("gurobi")
@@ -23,7 +21,7 @@ test_that("binary decisions", {
   s1 <- solve(p1)
   s2 <- solve(p2)
   # tests
-  expect_is(s1, "SpatRaster")
+  expect_inherits(s1, "SpatRaster")
   expect_equal(terra::nlyr(s1), 1)
   expect_true(all_binary(s1))
   expect_true(is_comparable_raster(sim_pu_raster, s1))
@@ -46,7 +44,7 @@ test_that("proportion decisions", {
   # solve problem
   s <- solve(p)
   # tests
-  expect_is(s, "SpatRaster")
+  expect_inherits(s, "SpatRaster")
   expect_equal(terra::nlyr(s), 1)
   expect_gte(min(terra::values(s), na.rm = TRUE), 0)
   expect_lte(max(terra::values(s), na.rm = TRUE), 1)
@@ -57,7 +55,7 @@ test_that("proportion decisions", {
 test_that("proportion decisions (floating point)", {
   skip_on_cran()
   skip_if_not_installed("gurobi")
-  skip_if_not_installed("prioritizrdata", minimum_version = "0.3.0.0")
+  skip_if_not_installed("prioritizrdata", minimum_version = "0.3.0")
   # load data
   tas_pu <- prioritizrdata::get_tas_pu()
   tas_features <- prioritizrdata::get_tas_features()
@@ -72,10 +70,10 @@ test_that("proportion decisions (floating point)", {
   # solve problem
   s <- solve(p)
   # tests
-  expect_is(s, "sf")
+  expect_inherits(s, "sf")
   expect_true("solution_1" %in% names(s))
   expect_equal(nrow(s), nrow(tas_pu))
-  expect_is(s$solution_1, "numeric")
+  expect_inherits(s$solution_1, "numeric")
   expect_gte(min(s$solution_1), 0)
   expect_lte(max(s$solution_1), 1)
 })
@@ -124,7 +122,7 @@ test_that("mix of binary and continuous variables", {
   # solve problem
   s <- solve(p)
   # tests
-  expect_is(s, "SpatRaster")
+  expect_inherits(s, "SpatRaster")
   expect_equal(terra::nlyr(s), 1)
   expect_true(all_binary(s))
   expect_true(is_comparable_raster(sim_pu_raster, s))
@@ -146,7 +144,7 @@ test_that("first_feasible", {
   # solve problem
   s1 <- solve(p1)
   # check that solution has correct properties
-  expect_is(s1, "SpatRaster")
+  expect_inherits(s1, "SpatRaster")
   expect_equal(terra::nlyr(s1), 1)
   expect_true(all_binary(s1))
   expect_true(is_comparable_raster(sim_pu_raster, s1))
