@@ -1,5 +1,3 @@
-context("add_manual_targets")
-
 test_that("add_manual_targets (default, single zone)", {
   # import data
   sim_pu_raster <- get_sim_pu_raster()
@@ -18,15 +16,14 @@ test_that("add_manual_targets (default, single zone)", {
   targets <- p$targets$output()
   # tests
   print(p)
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, seq_len(terra::nlyr(sim_features))[-1])
-  expect_equivalent(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1)
-  )
+  expect_equal(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1))
   expect_equal(targets$value, as.numeric(seq_len(4)))
   expect_equal(targets$sense, rep(">=", terra::nlyr(sim_features) - 1))
 })
@@ -49,14 +46,14 @@ test_that("add_manual_targets (mixed, single zone)", {
   targets <- p$targets$output()
   # run tests
   print(p)
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, seq_len(terra::nlyr(sim_features))[-1])
-  expect_equivalent(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1))
+  expect_equal(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1))
   expect_equal(targets$sense, rep(">=", terra::nlyr(sim_features) - 1))
   expect_equal(
     targets$value,
@@ -83,14 +80,14 @@ test_that("add_manual_targets (explicit, single zone)", {
   # calculate absolute targets
   targets <- p$targets$output()
   # tests
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, seq_len(terra::nlyr(sim_features))[-1])
-  expect_equivalent(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1))
+  expect_equal(unlist(targets$zone), rep(1, terra::nlyr(sim_features) - 1))
   expect_equal(targets$value, 2:5)
   expect_equal(targets$sense, c(">=", "=", "<=", "="))
 })
@@ -113,14 +110,14 @@ test_that("add_manual_targets (default, multiple zones)", {
   # calculate absolute targets
   targets <- p$targets$output()
   # tests
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, c(1, 1, 2, 3))
-  expect_equivalent(unlist(targets$zone), c(1, 2, 1, 3))
+  expect_equal(unlist(targets$zone), c(1, 2, 1, 3))
   expect_equal(targets$value, 4:7)
   expect_equal(targets$sense, rep(">=", 4))
 })
@@ -144,14 +141,14 @@ test_that("add_manual_targets (explicit, multiple zones)", {
   # calculate absolute targets
   targets <- p$targets$output()
   # tests
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, c(1, 1, 2, 3))
-  expect_equivalent(targets$zone, list(1, 2, 1, c(1, 2)))
+  expect_equal(targets$zone, list(1, 2, 1, c(1, 2)))
   expect_equal(targets$value, 4:7)
   expect_equal(targets$sense, c(">=", "<=", "=", ">="))
 })
@@ -178,14 +175,14 @@ test_that("add_manual_targets (explicit, multiple zones)", {
   # calculate absolute targets
   targets <- p$targets$output()
   # tests
-  expect_is(targets, "tbl_df")
+  expect_inherits(targets, "tbl_df")
   expect_true(all(names(targets) == c("feature", "zone", "sense", "value")))
-  expect_is(targets$feature, "integer")
-  expect_is(targets$zone, "list")
-  expect_is(targets$value, "numeric")
-  expect_is(targets$sense, "character")
+  expect_inherits(targets$feature, "integer")
+  expect_inherits(targets$zone, "list")
+  expect_inherits(targets$value, "numeric")
+  expect_inherits(targets$sense, "character")
   expect_equal(targets$feature, c(1, 1, 2, 3))
-  expect_equivalent(targets$zone, list(1, 2, 1, c(1, 2)))
+  expect_equal(targets$zone, list(1, 2, 1, c(1, 2)))
   expect_equal(targets$value, c(-1, -2, 1, 2))
   expect_equal(targets$sense, c(">=", "<=", "=", ">="))
 })
